/***************************************************************************
                          graphics.h  -  description
                             -------------------
    begin                : Sat Jan 1 2000
    copyright            : (C) 2000 by Perdig
    email                : perdig@linuxbr.com.br

    $Id: graphics.h,v 1.12 2000/11/26 20:34:55 perdig Exp $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef _GRAPHICS_H
#define _GRAPHICS_H

#include "config.h"

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/xpm.h>
#include <X11/Xutil.h>
#include <X11/keysym.h>
#include <stdio.h>
#include <stdlib.h>

// No Icon, so no icon name
#define ICON_NAME ""

// Default window size
#define DEFAULT_WINDOW_WIDTH 480 + 134
#define DEFAULT_WINDOW_HEIGHT 480 + 2

// Default colors
#define COLOR_BACK "rgb:00/00/00"
#define COLOR_TEXT "rgb:FF/FF/FF"

// Drawing functions

void blit(Pixmap src, Drawable dest, int x, int y, int w, int h);

void s_blit(Pixmap src, Drawable dest, int x, int y, int w, int h);

void us_blit(Pixmap src, Drawable dest, int x, int y, int w, int h);

void m_blit(Pixmap srcPix, Pixmap srcMask, Drawable dest, int x, int y,
						int w, int h);

void i_blit(XImage *src, Drawable dest, int x, int y, int w, int h);

void si_blit(XImage *src, Drawable dest, int x, int y, int w, int h);

void usi_blit(XImage *src, Drawable dest, int x, int y, int w, int h);

void rect(Drawable dest, int x, int y, int w, int h, unsigned long color_index,
					int filled);

void point(Drawable dest, int x, int y, unsigned long color_index);

void text(Drawable dest, int x, int y, const char *text_string,
					unsigned long color_index, int font);

void circle(Drawable dest, int x, int y, int w, int h, unsigned long color_index, 
					  int filled);

// Image manipulation

XImage *get_image(Pixmap src, int x, int y, int w, int h);

#define get_pixel(src, x, y) XGetPixel(src, x, y);
#define put_pixel(src, x, y, pixel) XPutPixel(src, x, y, pixel);

// Color manipulation

unsigned long get_color(const char *color_string);

void alloc_color(XColor *color);

void query_color(XColor *color);

// Infrastructure functions

int init_display();

void resize_window(int width, int height);

int load_pixmap(Pixmap *pix, Pixmap *mask, char *filename, int *width,
	               int *height);

Pixmap create_pixmap(int width, int height);

void graphics_sync();

void close_display();

// Misc functions

Pixmap dbuffer();

KeySym check_key();

KeySym wait_key();

KeySym wait_char(char *str);

void wait_time(long diff);

void text_rectangle(const char *txt, int font, int *w, int *h);

int text_width(char *txt, int font);
int text_height(int font);


#endif
